==> huaweicloudsdkhss-3.1.99-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/check_rule_id_list_request_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckRuleIdListRequestInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'check_rules': 'list[CheckRuleKeyInfoRequestInfo]'
    }

    attribute_map = {
        'check_rules': 'check_rules'
    }

    def __init__(self, check_rules=None):
        """CheckRuleIdListRequestInfo

        The model defined in huaweicloud sdk

        :param check_rules: 检查项ID列表
        :type check_rules: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        
        

        self._check_rules = None
        self.discriminator = None

        if check_rules is not None:
            self.check_rules = check_rules

    @property
    def check_rules(self):
        """Gets the check_rules of this CheckRuleIdListRequestInfo.

        检查项ID列表

        :return: The check_rules of this CheckRuleIdListRequestInfo.
        :rtype: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        return self._check_rules

    @check_rules.setter
    def check_rules(self, check_rules):
        """Sets the check_rules of this CheckRuleIdListRequestInfo.

        检查项ID列表

        :param check_rules: The check_rules of this CheckRuleIdListRequestInfo.
        :type check_rules: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        self._check_rules = check_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckRuleIdListRequestInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkhss-3.1.153-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/check_rule_id_list_request_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckRuleIdListRequestInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'check_rules': 'list[CheckRuleKeyInfoRequestInfo]'
    }

    attribute_map = {
        'check_rules': 'check_rules'
    }

    def __init__(self, check_rules=None):
        r"""CheckRuleIdListRequestInfo

        The model defined in huaweicloud sdk

        :param check_rules: 检查项ID列表
        :type check_rules: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        
        

        self._check_rules = None
        self.discriminator = None

        if check_rules is not None:
            self.check_rules = check_rules

    @property
    def check_rules(self):
        r"""Gets the check_rules of this CheckRuleIdListRequestInfo.

        检查项ID列表

        :return: The check_rules of this CheckRuleIdListRequestInfo.
        :rtype: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        return self._check_rules

    @check_rules.setter
    def check_rules(self, check_rules):
        r"""Sets the check_rules of this CheckRuleIdListRequestInfo.

        检查项ID列表

        :param check_rules: The check_rules of this CheckRuleIdListRequestInfo.
        :type check_rules: list[:class:`huaweicloudsdkhss.v5.CheckRuleKeyInfoRequestInfo`]
        """
        self._check_rules = check_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckRuleIdListRequestInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
